@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package App::Cronjob;
 {
-  $App::Cronjob::VERSION = '1.200002';
+  $App::Cronjob::VERSION = '1.200003';
 }
 # ABSTRACT: wrap up programs to be run as cron jobs
 
@@ -12,6 +12,7 @@ use Fcntl qw( :DEFAULT :flock );
 use Getopt::Long::Descriptive;
 use IPC::Run3 qw(run3);
 use Log::Dispatchouli;
+use Process::Status 0.002;
 use String::Flogger;
 use Sys::Hostname::Long;
 use Text::Template;
@@ -100,30 +101,25 @@ sub run {
     $logger->log_fatal([ 'run3 failed to run command: %s', $@ ])
       unless eval { run3($opt->{command}, \undef, \$output, \$output); 1; };
 
-    my %waitpid = (
-      status => $?,
-      exit   => $? >> 8,
-      signal => $? & 127,
-      core   => $? & 128,
-    );
+    my $status = Process::Status->new;
 
     my $end = Time::HiRes::time;
 
-    my $send_mail = ($waitpid{status} != 0)
+    my $send_mail = ($status->exitstatus != 0)
                  || (length $output && ! $opt->{errors_only});
 
     my $time_taken = sprintf '%0.4f', $end - $start;
 
     $logger->log([
       'job completed with status %s after %ss',
-      \%waitpid,
+      $status->as_struct,
       $time_taken,
     ]);
 
     if ($send_mail) {
       send_cronjob_report({
-        is_fail => (!! $waitpid{status}),
-        waitpid => \%waitpid,
+        is_fail => (!! $status->exitstatus),
+        status  => $status,
         time    => \$time_taken,
         output  => \$output,
       });
@@ -162,7 +158,6 @@ sub run {
 
 sub send_cronjob_report {
   my ($arg) = @_;
-  my $waitpid = $arg->{waitpid} || { no_result => 'never ran' };
 
   require Email::Simple;
   require Email::Simple::Creator;
@@ -175,7 +170,7 @@ sub send_cronjob_report {
       command => \$opt->{command},
       output  => $arg->{output},
       time    => $arg->{time} || \'(n/a)',
-      waitpid => $waitpid,
+      status  => \($arg->{status} ? $arg->{status}->as_string : 'never ran'),
     },
   );
 
@@ -207,7 +202,7 @@ BEGIN {
 $TEMPLATE = <<'END_TEMPLATE'
 Command: { $command }
 Time   : { $time }s
-Status : { String::Flogger->flog([ '%s', \%waitpid ]) }
+Status : { $status }
 
 Output :
 
@@ -218,7 +213,7 @@ END_TEMPLATE
 {
   package App::Cronjob::Exception;
 {
-  $App::Cronjob::Exception::VERSION = '1.200002';
+  $App::Cronjob::Exception::VERSION = '1.200003';
 }
   sub new {
     my ($class, $type, $text) = @_;
@@ -240,7 +235,7 @@ App::Cronjob - wrap up programs to be run as cron jobs
 
 =head1 VERSION
 
-version 1.200002
+version 1.200003
 
 =head1 SEE INSTEAD
 
